.. _recipe_asr.setup.displacements:

asr.setup.displacements
=======================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setup.displacements`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.setup.displacements.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setup.displacements

or as a python module

.. code-block:: console

   $ python -m asr.setup.displacements

Detailed description
--------------------
Module for generating atomic structures with displaced atoms.

Steps
-----


asr.setup.displacements
^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.displacements.main
   